All pastes #65961 Raw Edit

Anonymous

public text v1 · immutable
#65961 ·published 2006-06-15 20:07 UTC
rendered paste body
menu Nicklist {
  Auto
  .Voice
  ..Add: autovoice $$1
  ..Del: delvoice $$1
  .Hop
  ..Add: autohop $$1
  ..Del: delhop $$1
  .Op
  ..Add: autoop $$1
  ..Del: delop $$1
}

alias autoop {
  writeini -n auto.ini Auto_Op $nick $address($$1,2)
  echo -a $$1 successfully added to the auto-op list!
}

alias delop {
  remini auto.ini Auto_Op $nick $address($$1,2)
  echo -a $$1 successfully removed from the auto-op list!
}

alias autohop {
  writeini -n auto.ini Auto_Hop $nick $address($$1,2)
  echo -a $$1 successfully added to the auto-halfop list!
}

alias delhop {
  remini auto.ini Auto_Hop $nick $address($$1,2) 
  echo -a $$1 successfully removed from the auto-halfop list!
}

alias autovoice {
  writeini -n auto.ini Auto_Voice $nick $address($$1,2)
  echo -a $$1 successfully added to the auto-voice list!
}

alias delvoice {
  remini auto.ini Auto_Voice $nick $address($$1,2)
  echo -a $$1 successfully removed from the auto-voice list!
}

;on *:JOIN:#:{ $read(auto.ini, w $address($1,2))
;timer 1 3 if ($nick isreg $chan) mode # +v $nick }